@@ -25,7 +25,7 @@ class BaseClient(object):
         priv_key,
         priv_key_passphrase,
         host,
-        user,
+        username,
         password,
         verify=False,
         http_client=requests,
@@ -36,7 +36,7 @@ class BaseClient(object):
         self.session = http_client.Session()
         self.session.headers.update({'Content-Type': 'application/xml'})
         self.session.verify = verify
-        self.session.auth = (user, password)
+        self.session.auth = (username, password)
 
         if priv_key_passphrase:
             self.priv_key_passphrase = priv_key_passphrase.encode('ascii')
@@ -64,7 +64,7 @@ class BaseClient(object):
         soap_request = self._build_request(orden.build_xml())
         response = self.session.post(data=etree.tostring(soap_request), url=self.host)
         response.raise_for_status()
-        respuesta = respuesta_cls.parse_respuesta(response.text)
+        respuesta = respuesta_cls.parse_xml(response.text)
         logger.info(respuesta)
         return respuesta
 
